@@ -3,12 +3,8 @@ use swc_ecma_ast::*;
 use swc_ecma_utils::ExprExt;
 
 use super::Pure;
-use crate::mode::Mode;
 
-impl<M> Pure<'_, M>
-where
-    M: Mode,
-{
+impl Pure<'_> {
     /// Drop arguments of `Symbol()` call.
     pub(super) fn drop_arguments_of_symbol_call(&mut self, e: &mut CallExpr) {
         if !self.options.unsafe_symbols {
